@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: cli.py 1013 2010-10-20 01:06:10Z pronovic $
+# Revision : $Id: cli.py 1022 2011-10-11 23:27:49Z pronovic $
 # Purpose  : Provides command-line interface implementation.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -377,7 +377,7 @@ class _ActionItem(object):
       logger.debug("Calling action function [%s], execution index [%d]" % (name, self.index))
       self.function(configPath, options, config)
 
-   def _executeHook(self, type, hook):  # pylint: disable-msg=W0622,R0201
+   def _executeHook(self, type, hook):  # pylint: disable=W0622,R0201
       """
       Executes a hook command via L{util.executeCommand()}.
       @param type: String describing the type of hook, for logging.
