@@ -9,7 +9,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2008,2010 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008,2010,2014 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: test.py 999 2010-07-07 19:58:25Z pronovic $
+# Revision : $Id: test.py 1083 2014-10-07 19:17:12Z pronovic $
 # Purpose  : Run all of the unit tests for the project.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -164,8 +164,10 @@ def main():
       from testcase import subversiontests
       from testcase import mboxtests
       from testcase import encrypttests
+      from testcase import amazons3tests
       from testcase import splittests
       from testcase import spantests
+      from testcase import synctests
       from testcase import capacitytests
       from testcase import customizetests
    except ImportError, e:
@@ -223,7 +225,9 @@ def main():
    if args == [] or "mbox" in args: unittests["mbox"] = mboxtests.suite()
    if args == [] or "split" in args: unittests["split"] = splittests.suite()
    if args == [] or "encrypt" in args: unittests["encrypt"] = encrypttests.suite()
+   if args == [] or "amazons3" in args: unittests["amazons3"] = amazons3tests.suite()
    if args == [] or "span" in args: unittests["span"] = spantests.suite()
+   if args == [] or "sync" in args: unittests["sync"] = synctests.suite()
    if args == [] or "capacity" in args: unittests["capacity"] = capacitytests.suite()
    if args == [] or "customize" in args: unittests["customize"] = customizetests.suite()
    if args != []: print "*** Executing specific tests: %s" % unittests.keys()
